Arithmetic
----------

.. currentmodule:: prismstudio


.. autosummary::
    :toctree: api/

    _PrismComponent.abs
    _PrismComponent.sin
    _PrismComponent.sinh
    _PrismComponent.cos
    _PrismComponent.cosh
    _PrismComponent.tan
    _PrismComponent.tanh
    _PrismComponent.arcsin
    _PrismComponent.arcsinh
    _PrismComponent.arccos
    _PrismComponent.arccosh
    _PrismComponent.arctan
    _PrismComponent.arctanh
    _PrismComponent.round
    _PrismComponent.ceil
    _PrismComponent.floor
    _PrismComponent.sqrt
    _PrismComponent.exp
    _PrismComponent.ln
    _PrismComponent.log_n
    _PrismComponent.sign
    _PrismComponent.degrees
    _PrismComponent.radians
    _PrismComponent.clip
    max
    min
    mean
    var
    std
    sum



